@@ -27,6 +27,7 @@ class TransformAuth:  # noqa: D
         mql_server_url: Optional[str] = None,
         override_config: bool = True,
         use_async: bool = False,
+        target_org_id: Optional[int] = None,  # no-op for non-admin use
     ) -> None:
         self.__user_state: Optional[UserState] = None
         self.__mql_server_url: Optional[str] = None
@@ -34,6 +35,7 @@ class TransformAuth:  # noqa: D
         self.__auth_header: Optional[Dict[str, str]] = None
         self.__api_key: Optional[str] = None
         self._use_async = use_async
+        self.target_org_id = target_org_id
         self.config = ConfigHandler(override_config)
 
         # Overrides
@@ -60,6 +62,11 @@ class TransformAuth:  # noqa: D
             raise AuthException
 
         self.__api_key = api_key
+
+        # Remove bearer token auth if exists
+        self.config._remove_config_value(BEARER_TOKEN_CONFIG_KEY)
+        self.config._remove_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY)
+
         self.config._set_config_value(API_KEY_CONFIG_KEY, api_key)
 
     @property
@@ -78,6 +85,7 @@ class TransformAuth:  # noqa: D
     @bearer_token.setter
     def bearer_token(self, bearer_token: str) -> None:  # noqa: D
         self.config._set_config_value(BEARER_TOKEN_CONFIG_KEY, bearer_token)
+        self.config._remove_config_value(API_KEY_CONFIG_KEY)
 
     @property
     def bearer_token_expires_at(self) -> Optional[str]:
@@ -98,6 +106,10 @@ class TransformAuth:  # noqa: D
                 self.__auth_header = {"Authorization": f"Bearer {self.bearer_token}"}
         if self.__auth_header is None:
             raise AuthException
+
+        if self.target_org_id is not None:
+            self.__auth_header["X-Target-Org-Id"] = str(self.target_org_id)
+
         return self.__auth_header
 
     @property
@@ -233,6 +245,9 @@ class ConfigHandler:
             with open(self.config_file_path) as f:
                 configs = yaml.load(f, Loader=yaml.SafeLoader) or {}
 
+        if key not in configs:
+            return
+
         del configs[key]
 
         with open(self.config_file_path, "w") as f:
